==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapOTPPolicyEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapOTPPolicyEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapOTPPolicyEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> entityFieldDelegate;
    public MapOTPPolicyEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyInitialCounter() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyInitialCounter(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyDigits() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyDigits(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyLookAheadWindow() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyLookAheadWindow(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyPeriod() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyPeriod(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOtpPolicyType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOtpPolicyAlgorithm() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyAlgorithm(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOtpPolicyCodeReusable() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_CODE_REUSABLE);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyCodeReusable(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_CODE_REUSABLE, p0);
    }
}

==> keycloak-model-map-22.0.5-sources.jar: org/keycloak/models/map/realm/entity/MapOTPPolicyEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapOTPPolicyEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapOTPPolicyEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> entityFieldDelegate;
    public MapOTPPolicyEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyInitialCounter() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyInitialCounter(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyDigits() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyDigits(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyLookAheadWindow() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyLookAheadWindow(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getOtpPolicyPeriod() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyPeriod(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOtpPolicyType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOtpPolicyAlgorithm() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyAlgorithm(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOtpPolicyCodeReusable() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_CODE_REUSABLE);
    }
    @SuppressWarnings("unchecked") @Override public void setOtpPolicyCodeReusable(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_CODE_REUSABLE, p0);
    }
}
